==> kubernetes-model-1.0.46-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class HorizontalPodAutoscalerStatusBuilder extends HorizontalPodAutoscalerStatusFluentImpl<HorizontalPodAutoscalerStatusBuilder> implements VisitableBuilder<HorizontalPodAutoscalerStatus,HorizontalPodAutoscalerStatusBuilder>{

     HorizontalPodAutoscalerStatusFluent<?> fluent;
public HorizontalPodAutoscalerStatusBuilder(){
    this(new HorizontalPodAutoscalerStatus());
}
public HorizontalPodAutoscalerStatusBuilder( HorizontalPodAutoscalerStatusFluent<?> fluent ){
    this(fluent, new HorizontalPodAutoscalerStatus());
}
public HorizontalPodAutoscalerStatusBuilder( HorizontalPodAutoscalerStatusFluent<?> fluent , HorizontalPodAutoscalerStatus instance ){
    this.fluent = fluent; fluent.withCurrentCPUUtilizationPercentage(instance.getCurrentCPUUtilizationPercentage()); fluent.withCurrentReplicas(instance.getCurrentReplicas()); fluent.withDesiredReplicas(instance.getDesiredReplicas()); fluent.withLastScaleTime(instance.getLastScaleTime()); fluent.withObservedGeneration(instance.getObservedGeneration()); 
}
public HorizontalPodAutoscalerStatusBuilder( HorizontalPodAutoscalerStatus instance ){
    this.fluent = this; this.withCurrentCPUUtilizationPercentage(instance.getCurrentCPUUtilizationPercentage()); this.withCurrentReplicas(instance.getCurrentReplicas()); this.withDesiredReplicas(instance.getDesiredReplicas()); this.withLastScaleTime(instance.getLastScaleTime()); this.withObservedGeneration(instance.getObservedGeneration()); 
}

public EditableHorizontalPodAutoscalerStatus build(){
    EditableHorizontalPodAutoscalerStatus buildable = new EditableHorizontalPodAutoscalerStatus(fluent.getCurrentCPUUtilizationPercentage(),fluent.getCurrentReplicas(),fluent.getDesiredReplicas(),fluent.getLastScaleTime(),fluent.getObservedGeneration());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
HorizontalPodAutoscalerStatusBuilder that = (HorizontalPodAutoscalerStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class HorizontalPodAutoscalerStatusBuilder extends HorizontalPodAutoscalerStatusFluentImpl<HorizontalPodAutoscalerStatusBuilder> implements VisitableBuilder<HorizontalPodAutoscalerStatus,HorizontalPodAutoscalerStatusBuilder>{

     HorizontalPodAutoscalerStatusFluent<?> fluent;
public HorizontalPodAutoscalerStatusBuilder(){
    this(new HorizontalPodAutoscalerStatus());
}
public HorizontalPodAutoscalerStatusBuilder( HorizontalPodAutoscalerStatusFluent<?> fluent ){
    this(fluent, new HorizontalPodAutoscalerStatus());
}
public HorizontalPodAutoscalerStatusBuilder( HorizontalPodAutoscalerStatusFluent<?> fluent , HorizontalPodAutoscalerStatus instance ){
    this.fluent = fluent; fluent.withCurrentCPUUtilizationPercentage(instance.getCurrentCPUUtilizationPercentage()); fluent.withCurrentReplicas(instance.getCurrentReplicas()); fluent.withDesiredReplicas(instance.getDesiredReplicas()); fluent.withLastScaleTime(instance.getLastScaleTime()); fluent.withObservedGeneration(instance.getObservedGeneration()); 
}
public HorizontalPodAutoscalerStatusBuilder( HorizontalPodAutoscalerStatus instance ){
    this.fluent = this; this.withCurrentCPUUtilizationPercentage(instance.getCurrentCPUUtilizationPercentage()); this.withCurrentReplicas(instance.getCurrentReplicas()); this.withDesiredReplicas(instance.getDesiredReplicas()); this.withLastScaleTime(instance.getLastScaleTime()); this.withObservedGeneration(instance.getObservedGeneration()); 
}

public HorizontalPodAutoscalerStatus build(){
    HorizontalPodAutoscalerStatus buildable = new HorizontalPodAutoscalerStatus(fluent.getCurrentCPUUtilizationPercentage(),fluent.getCurrentReplicas(),fluent.getDesiredReplicas(),fluent.getLastScaleTime(),fluent.getObservedGeneration());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
HorizontalPodAutoscalerStatusBuilder that = (HorizontalPodAutoscalerStatusBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
